==> virtualbox-sdk-6.0.8-2-x86_64.pkg.tar.xz: org/virtualbox_6_0/jaxws/ISystemPropertiesGetMaxInstancesOfUSBControllerType.java <==

package org.virtualbox_6_0.jaxws;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element name="_this" type="{http://www.w3.org/2001/XMLSchema}string"/>
 *         &lt;element name="chipset" type="{http://www.virtualbox.org/}ChipsetType"/>
 *         &lt;element name="type" type="{http://www.virtualbox.org/}USBControllerType"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "_this",
    "chipset",
    "type"
})
@XmlRootElement(name = "ISystemProperties_getMaxInstancesOfUSBControllerType")
public class ISystemPropertiesGetMaxInstancesOfUSBControllerType {

    @XmlElement(required = true)
    protected String _this;
    @XmlElement(required = true)
    protected ChipsetType chipset;
    @XmlElement(required = true)
    protected USBControllerType type;

    /**
     * Gets the value of the this property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getThis() {
        return _this;
    }

    /**
     * Sets the value of the this property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setThis(String value) {
        this._this = value;
    }

    /**
     * Gets the value of the chipset property.
     * 
     * @return
     *     possible object is
     *     {@link ChipsetType }
     *     
     */
    public ChipsetType getChipset() {
        return chipset;
    }

    /**
     * Sets the value of the chipset property.
     * 
     * @param value
     *     allowed object is
     *     {@link ChipsetType }
     *     
     */
    public void setChipset(ChipsetType value) {
        this.chipset = value;
    }

    /**
     * Gets the value of the type property.
     * 
     * @return
     *     possible object is
     *     {@link USBControllerType }
     *     
     */
    public USBControllerType getType() {
        return type;
    }

    /**
     * Sets the value of the type property.
     * 
     * @param value
     *     allowed object is
     *     {@link USBControllerType }
     *     
     */
    public void setType(USBControllerType value) {
        this.type = value;
    }

}

==> virtualbox-sdk-6.0.14-1-x86_64.pkg.tar.xz: org/virtualbox_6_0/jaxws/ISystemPropertiesGetMaxInstancesOfUSBControllerType.java <==

package org.virtualbox_6_0.jaxws;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlSchemaType;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element name="_this" type="{http://www.w3.org/2001/XMLSchema}string"/>
 *         &lt;element name="chipset" type="{http://www.virtualbox.org/}ChipsetType"/>
 *         &lt;element name="type" type="{http://www.virtualbox.org/}USBControllerType"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "_this",
    "chipset",
    "type"
})
@XmlRootElement(name = "ISystemProperties_getMaxInstancesOfUSBControllerType")
public class ISystemPropertiesGetMaxInstancesOfUSBControllerType {

    @XmlElement(required = true)
    protected String _this;
    @XmlElement(required = true)
    @XmlSchemaType(name = "string")
    protected ChipsetType chipset;
    @XmlElement(required = true)
    @XmlSchemaType(name = "string")
    protected USBControllerType type;

    /**
     * Gets the value of the this property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getThis() {
        return _this;
    }

    /**
     * Sets the value of the this property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setThis(String value) {
        this._this = value;
    }

    /**
     * Gets the value of the chipset property.
     * 
     * @return
     *     possible object is
     *     {@link ChipsetType }
     *     
     */
    public ChipsetType getChipset() {
        return chipset;
    }

    /**
     * Sets the value of the chipset property.
     * 
     * @param value
     *     allowed object is
     *     {@link ChipsetType }
     *     
     */
    public void setChipset(ChipsetType value) {
        this.chipset = value;
    }

    /**
     * Gets the value of the type property.
     * 
     * @return
     *     possible object is
     *     {@link USBControllerType }
     *     
     */
    public USBControllerType getType() {
        return type;
    }

    /**
     * Sets the value of the type property.
     * 
     * @param value
     *     allowed object is
     *     {@link USBControllerType }
     *     
     */
    public void setType(USBControllerType value) {
        this.type = value;
    }

}
